@@ -259,12 +259,21 @@ class ESXMon(Archiver):
                 instance_list=wbemclient.EnumerateInstances(cls)
             except pywbem.cim_operations.CIMError, e:
                 if e.args[0]==pywbem.CIM_ERR_NOT_FOUND:
-                    log.warning('class %s: %s', cls, e.args[1])
+                    log.warning('class not found: %s (%s)', cls, e.args[1])
                     continue
                 else:
-                    raise
+                    log.exception('Unexpected error enumerating class %s', cls)
+                    continue
+                
+            buggy=False
             for instance in instance_list:
-                elementName=instance['ElementName']
+                try:
+                    elementName=instance['ElementName']
+                except KeyError:
+                    if not buggy:
+                        log.error('Skip unknown buggy instance in class %s', cls)
+                        buggy=True
+                    continue
                 title='===== %s %s =====' % (cls, elementName)
                 for propertyName in sorted(instance.keys()):
                     fullPropertyName="%s.%s.%s" % (cls, elementName, propertyName)
