@@ -31,7 +31,7 @@ import ConfigParser
 
 from datetime import datetime, timedelta
 
-from archiver import boolean, check_mail_config, Destinations, sendmail, Manager, send_mail_report, ftp_url_re
+from archiver import boolean, check_mail_config, Destinations, sendmail, Manager, send_mail_report, write_status, ftp_url_re
 
 import cron
 
@@ -159,10 +159,7 @@ def gen_status(start, job, status, end):
     return st
 
 # ---------------------------------------------------------------------------        
-def mail_exception(start, job, extra, manager, subject):
-    
-    status=gen_status(start, job, 'ERR', None)
-    status+='runtime_error=%r\r\n' % sys.exc_info()[1]
+def mail_exception(start, job, extra, manager, subject, status):
     
     msg_body=job['msg_header']
     msg_body+='\nUnexpected error, read "traceback.txt" for more\n\n'
@@ -190,7 +187,7 @@ def mail_exception(start, job, extra, manager, subject):
     except Exception:
         msg_body+='\nminor error when attaching logging\n'                      
     
-    errmsg=sendmail(job, subject, msg_body, attachments, manager.log)
+    errmsg=sendmail(job, subject, msg_body, attachments, manager.log, 'exception')
 
 
 class MyFormatter(logging.Formatter):
@@ -235,6 +232,7 @@ def main():
     parser.add_option("-v", "--verbose", dest="verbose", action="store_true", default=True, help="write logging to the terminal (default)")
     parser.add_option("-q", "--quiet", dest="verbose", action="store_false", default=True, help="don't write logging to the terminal")
     parser.add_option("-l", "--logfile", dest="logfile", default='mksbackup.log', help="log to this file", metavar="logfile")
+    parser.add_option("-s", "--statusdir", dest="statusdir", default=None, help="the directory where to write status of this backup", metavar="statusdir")
     parser.add_option("-e", "--encoding", dest="encoding", default='auto', help="configuration file encoding", metavar="encoding")
     
     parser.add_option("-i", "--install", dest="install", action="store_true", help="install and pre-setup a task in scheduler")
@@ -455,10 +453,17 @@ def main():
                 log.exception('loading job %s by program %s', job_name, program)
             except UnicodeDecodeError:
                 log.error('loading job %s by program %s: %s', job_name, program, ErrorDecode(e, default_encoding))
-                
+
+            status=gen_status(start, job, 'ERR', None)
+            status+='runtime_error=%r\r\n' % sys.exc_info()[1]
+    
             if job['mail'] and not mail_config_errors:
                 subject='MKSBACKUP %s ERR %s ' % (command_display, job['name'], )
-                mail_exception(start, job, '', manager, subject)
+                mail_exception(start, job, '', manager, subject, status)
+            
+            if cmd_options.statusdir:
+                write_status(status, cmd_options.statusdir, job['name'])
+            
             continue
     
         for line in extra.split('\n'):
@@ -486,8 +491,10 @@ def main():
                 status=gen_status(start, job, 'ERR', None)
                 attachments=manager.attachments[:]
                 attachments.append(('status.txt', None, status.encode('utf-8'), 'text', 'plain', 'utf-8')),
-                errmsg=sendmail(job, subject, msg_body, attachments, manager.log)
-    
+                errmsg=sendmail(job, subject, msg_body, attachments, manager.log, 'err')
+                if cmd_options.statusdir:
+                    write_status(status, cmd_options.statusdir, job['name'])
+
             continue
     
         if warnings:
@@ -529,7 +536,7 @@ def main():
             msg_body='%s\n\n%s\n' % (msg_body, extra)
             if job['mail'] and command=='checkmail':
                 subject='MKSBACKUP %s OK %s ' % (command_display, job['name'], )
-                errmsg=sendmail(job, subject, msg_body, manager.attachments, manager.log)
+                errmsg=sendmail(job, subject, msg_body, manager.attachments, manager.log, 'check')
             continue 
     
         #print 'destination', destination
@@ -549,9 +556,16 @@ def main():
             except UnicodeDecodeError:
                 log.error('running command=%s job=%s archiver=%s : %s', command, job_name, program, ErrorDecode(e, default_encoding))
 
+            status=gen_status(start, job, 'ERR', None)
+            status+='runtime_error=%r\r\n' % sys.exc_info()[1]
+
             if job['mail']:
                 subject='MKSBACKUP BACKUP ERR %s ' % (job['name'], )
-                mail_exception(start, job, extra, manager, subject)
+                mail_exception(start, job, extra, manager, subject, status)
+
+            if cmd_options.statusdir:
+                write_status(status, cmd_options.statusdir, job['name'])
+                
         else:
             log.info('end command=%s job=%s archiver=%s', command, job_name, program)
     
@@ -561,6 +575,9 @@ def main():
                 if result[0]!='OK':
                     exit_code=max(exit_code, 1)
     
+                if cmd_options.statusdir:
+                    write_status(result[1], cmd_options.statusdir, job['name'])
+                    
                 errmsg=send_mail_report(job, result, manager)
 
         
