@@ -316,7 +316,7 @@ class SCPClient(object):
         try:
             mode = int(parts[0], 8)
             size = int(parts[1])
-            print 'ASX _recv_file', self._recv_dir, parts[2]
+            #print 'ASX _recv_file', self._recv_dir, parts[2]
             if os.path.isdir(self._recv_dir):
                 path = os.path.join(self._recv_dir, parts[2])
             else:
