@@ -181,7 +181,7 @@ class WbadminBase(Archiver):
                 else:
                     log.info('EventID 14 not found')
                     
-        if wba_process.returncode==0 and hresult=='0':
+        if wba_process.returncode==0 and hresult in ('0', '0x0') :
             ev_status='OK'
             flog=log.debug
         else:
